@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) 2011-2022 Yoran Heling
+  Copyright (c) Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -494,7 +494,7 @@ hub_t *hub_global_byid(guint64 id) {
 
 
 // Should be called when something changes that may affect our INF or $MyINFO.
-void hub_global_nfochange() {
+void hub_global_nfochange(void) {
   GHashTableIter i;
   g_hash_table_iter_init(&i, hubs);
   hub_t *h;
@@ -746,7 +746,7 @@ void hub_send_nfo(hub_t *hub) {
     // send non-changing stuff in the IDENTIFY state
     gboolean f = hub->state == ADC_S_IDENTIFY;
     if(f) {
-      g_string_append_printf(cmd, " ID%s PD%s VEncdc\\s%s", var_get(0, VAR_cid), var_get(0, VAR_pid), main_version);
+      g_string_append_printf(cmd, " ID%s PD%s APncdc VE%s", var_get(0, VAR_cid), var_get(0, VAR_pid), main_version);
       adc_append(cmd, "NI", hub->nick);
       // Always add our KP field, even if we're not active. Other clients may
       // validate our certificate even when we are the one connecting.
@@ -1028,7 +1028,7 @@ static void adc_sch(hub_t *hub, adc_cmd_t *cmd) {
 
   int i = 0;
   int max = (u->hasudp4 && u->udp4) || (u->hasudp6 && u->udp6) ? 10 : 5;
-  fl_list_t *res[max];
+  fl_list_t *res[10];
 
   // TTH lookup
   if(tr) {
