@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) 2011-2022 Yoran Heling
+  Copyright (c) Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -1518,7 +1518,7 @@ void net_udp_sendf(net_udp_t *udp, const char *fmt, ...) {
 
 // initialize some global structures
 
-void net_init_global() {
+void net_init_global(void) {
   ratecalc_init(&net_in);
   ratecalc_init(&net_out);
   // Don't group these with RCC_UP or RCC_DOWN, otherwise bandwidth will be counted twice.
