@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) 2011-2022 Yoran Heling
+  Copyright (c) Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -102,7 +102,7 @@ static int ui_cmdhist_search(gboolean backward, const char *q, int start) {
 }
 
 
-static void ui_cmdhist_save() {
+static void ui_cmdhist_save(void) {
   if(!cmdhist->ismod)
     return;
   cmdhist->ismod = FALSE;
@@ -126,7 +126,7 @@ static void ui_cmdhist_save() {
 }
 
 
-void ui_cmdhist_close() {
+void ui_cmdhist_close(void) {
   int i;
   ui_cmdhist_save();
   for(i=0; i<=CMDHIST_BUF; i++)
